@@ -1,7 +1,5 @@
-/*  xhamlog: A logging program for radio amateurs.
- *
- *
- *  This program is free software; you can redistribute it and/or
+/*
+ * This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
  *  the License, or (at your option) any later version.
@@ -14,10 +12,9 @@
  *  http://www.gnu.org/copyleft/gpl.txt
  */
 
+#ifndef MAIN_H
+#define MAIN_H      1
+
 #include "common.h"
 
-/* File name data */
-#define STATION_LOG_FILE	"station_log.txt"	/* Station text log name */
-#define STATION_QSL_FILE	"station_qsl.ps"	/* Station adif log name */
-#define STATION_ADIF_FILE	"station_log.adif"	/* Station adif log name */
-
+#endif
