@@ -1,6 +1,4 @@
-/* xhamlog: A logging program for radio amateurs.
- *
- *
+/*
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -23,8 +21,12 @@ rc_data_t rc_data;
 
 /* Global widgets */
 GtkWidget
-  *main_window,
-  *gbl_popup_menu;
+  *main_window = NULL,
+  *popup_menu  = NULL;
+
+GtkBuilder
+  *main_window_builder = NULL,
+  *popup_menu_builder  = NULL;
 
 /* QSO data record */
 qso_record_t qso_record;
