@@ -1,6 +1,4 @@
-/*  xhamlog: A logging program for radio amateurs.
- *
- *
+/*
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -14,7 +12,6 @@
  *  http://www.gnu.org/copyleft/gpl.txt
  */
 
-
 #include "common.h"
 
 /*-------------------------------------------------------------------------*/
@@ -25,7 +22,11 @@ extern rc_data_t rc_data;
 /* Global widgets */
 extern GtkWidget
   *main_window,
-  *gbl_popup_menu;
+  *popup_menu;
+
+extern GtkBuilder
+  *main_window_builder,
+  *popup_menu_builder;
 
 /* QSO data record */
 extern qso_record_t qso_record;
